@@ -30,7 +30,7 @@ exclude_patterns = []
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
-html_theme = 'sphinx_rtd_theme'
+html_theme = 'furo'
 # html_static_path = ['_static']
 
 # Example configuration for intersphinx: refer to the Python standard library.
